---
title: "Examples"
listing:
  contents: examples        # Map with examples
  type: grid                # View: 'grid', 'default' or 'table'
  sort: "date desc"         # Sort by date (newest first)
  categories: true          # Show categories in sidebar
  sort-ui: true             # User can sort
  filter-ui: true           # Search alloweed
  fields: [title, description, author, date, categories] # Fields from metadata
---

Here you can find several examples how 'brdr' can be used:


